@@ -22,7 +22,6 @@ _SYNC = '_SYNC'
 _ASYNC = '_ASYNC'
 
 def cpp23(inputdoc):
-    mode = None
     try:
         # in case we got an element tree
         cpp2doc = inputdoc.getroot()
@@ -30,7 +29,6 @@ def cpp23(inputdoc):
         # in case we got an element
         cpp2doc = inputdoc
     if cpp2doc.tag == cppa2('CollaborationProtocolProfile'):
-        mode = _CPPMODE
         outputdoc = lxml.etree.Element(cppa3('CPP'),
                                        nsmap= {'cppa': 'http://docs.oasis-open.org/ebcore/ns/cppa/v3.0',
                                                'ds': 'http://www.w3.org/2000/09/xmldsig#',
@@ -38,12 +36,11 @@ def cpp23(inputdoc):
         return _cppa23(cpp2doc, outputdoc, mode=_CPPMODE)
     else:
         raise Exception(
-            'Input document is not a CPP, root is {}, expecting {}'.format(cppa2doc.tag,
+            'Input document is not a CPP, root is {}, expecting {}'.format(cpp2doc.tag,
                                                                            cppa2('CollaborationProtocolProfile'))
         )
 
 def cpa23(inputdoc):
-    mode = None
     try:
         # in case we got an element tree
         cppa2doc = inputdoc.getroot()
@@ -51,7 +48,6 @@ def cpa23(inputdoc):
         # in case we got an element
         cppa2doc = inputdoc
     if cppa2doc.tag == cppa2('CollaborationProtocolAgreement'):
-        mode = _CPAMODE
         outputdoc = lxml.etree.Element(cppa3('CPA'),
                                        nsmap= {'cppa': 'http://docs.oasis-open.org/ebcore/ns/cppa/v3.0',
                                                'ds': 'http://www.w3.org/2000/09/xmldsig#',
@@ -218,17 +214,15 @@ def match_collaborationroles(party_info, counterparty_info, parent,
                                                                    version=process_version)
                 if process_uuid != None:
                     service_specification_element.set('uuid',process_uuid)
-                party_role_element = lxml.etree.SubElement(service_specification_element,
-                                                           cppa3('PartyRole'),
-                                                           name=party_role)
-                #party_role_element.text = party_role
-                counterparty_role_element = lxml.etree.SubElement(service_specification_element,
-                                                                cppa3('CounterPartyRole'),
-                                                                name=counterparty_role)
-                #counterparty_role_element.text= counterparty_role
+                lxml.etree.SubElement(service_specification_element,
+                                      cppa3('PartyRole'),
+                                      name=party_role)
+                lxml.etree.SubElement(service_specification_element,
+                                      cppa3('CounterPartyRole'),
+                                      name=counterparty_role)
                 # A role pair is only added if there is at least one ServiceBinding
                 # for the pair
-                at_least_one_matching_servicebinding = False
+                #at_least_one_matching_servicebinding = False
                 if match_servicebindings(collaborationrole, othercollaborationrole,
                     party_info, counterparty_info, service_specification_element,
                     matched_channels, matched_transports,
@@ -244,16 +238,15 @@ def match_collaborationroles(party_info, counterparty_info, parent,
                                                                version=process_version)
             if process_uuid != None:
                 service_specification_element.set('uuid',process_uuid)
-            party_role_element = lxml.etree.SubElement(service_specification_element,
-                                                       cppa3('PartyRole'),
-                                                       name=party_role)
-            #party_role_element.text = party_role
+            lxml.etree.SubElement(service_specification_element,
+                                  cppa3('PartyRole'),
+                                  name=party_role)
             counterparty_role = 'http://docs.oasis-open.org/ebxml-msg/ebms/v3.0/ns/core/200704/defaultRole'
-            counterparty_role_element = lxml.etree.SubElement(service_specification_element,
-                                                            cppa3('CounterPartyRole'),
-                                                            name=counterparty_role)
+            lxml.etree.SubElement(service_specification_element,
+                                  cppa3('CounterPartyRole'),
+                                  name=counterparty_role)
 
-            at_least_one_matching_servicebinding = True
+            #at_least_one_matching_servicebinding = True
             if match_servicebindings(collaborationrole, None,
                 party_info, counterparty_info, service_specification_element,
                 matched_channels, matched_transports,
@@ -448,10 +441,10 @@ def match_channels(party_info, counterparty_info, send_or_receive,
             'cppa2:DeliveryChannel[@cppa2:channelId="{}"]'.format(otherchannel_id),
             namespaces=_NSMAP
         )[0]
-        other_v2_messagingcharacteristics = other_v2_channel_id.xpath(
-            'cppa2:MessagingCharacteristics',
-            namespaces=_NSMAP
-        )[0]
+        #other_v2_messagingcharacteristics = other_v2_channel_id.xpath(
+        #    'cppa2:MessagingCharacteristics',
+        #    namespaces=_NSMAP
+        #)[0]
         other_v2_docexchange_id = other_v2_channel_id.xpath(
             '@cppa2:docExchangeId',
             namespaces=_NSMAP
@@ -463,8 +456,7 @@ def match_channels(party_info, counterparty_info, send_or_receive,
             namespaces=_NSMAP
         )[0]
     else:
-        other_v2_channel_id = other_v2_docexchange_id = other_v2_transport_id =\
-            other_v2_messagingcharacteristics = other_ebms_binding = None
+        other_v2_channel_id = other_v2_docexchange_id = other_v2_transport_id = other_ebms_binding = None
     matched_channel_id = xrefid(channel_id, otherchannel_id, package_id, send_or_receive, message_type)
     matched_transport_id = xrefid(this_v2_transport_id, other_v2_transport_id, package_id, send_or_receive)
     if syncmode == _ASYNC:
@@ -868,11 +860,17 @@ def match_transports(party_info, counterparty_info, send_or_receive,
                                                          othertransport_id,
                                                          '',
                                                          send_or_receive))
+        if len(transport_protocol_version_list) > 0:
+            http_version_element = lxml.etree.SubElement(unified_transport,
+                                                         cppa3('HTTPVersion'))
+            http_version_element.text = transport_protocol_version_list[0]
     elif transport_protocol_name == 'SMTP':
         unified_transport = lxml.etree.Element(cppa3('SMTPTransport'), id=xrefid(transport_id,
                                                          othertransport_id,
                                                          '',
                                                          send_or_receive))
+    else:
+        raise Exception('Unsupported protocol {}'.format(transport_protocol_name))
     if receiver_transport != None:
         endpoint_element = lxml.etree.SubElement(unified_transport,
                                                  cppa3('Endpoint'))
