@@ -13,9 +13,9 @@ TODO:
 
 import logging, traceback, re, isodate
 
-from unify import lookup_party_identifiers
+from .unify import lookup_party_identifiers
 
-from schema import cppa3_content_model
+from .schema import cppa3_content_model
 
 _NSMAP = {'cppa': 'http://docs.oasis-open.org/ebcore/ns/cppa/v3.0',
          'ds': 'http://www.w3.org/2000/09/xmldsig#',
@@ -428,7 +428,7 @@ def assert_equal(value_1, value_2):
         raise MatchException('{} != {}'.format(value_1, value_2))
 
 def retrieve_child_element(child_element_tag, parent_element):
-    local_name = re.split('\}', child_element_tag)[1]
+    local_name = re.split(r'}', child_element_tag)[1]
     child_element_list = parent_element.xpath(
         'cppa:'+local_name, namespaces=_NSMAP)
     if len(child_element_list) == 0:
@@ -441,7 +441,7 @@ def retrieve_child_element(child_element_tag, parent_element):
         return child_element_list[0]
 
 def match_simple_child_element(parent_element, child_element):
-    local_name = re.split('\}', child_element.tag)[1]
+    local_name = re.split(r'}', child_element.tag)[1]
     corresponding_elements = parent_element.xpath(
         'cppa:{}'.format(local_name),
         namespaces=_NSMAP
@@ -465,7 +465,7 @@ def match_simple_child_element(parent_element, child_element):
         logging.info('Found one {}'.format(child_element.tag))
 
 def match_channel_reference_element(cpp, parent_element, cpa, child_element, direction):
-    local_name = re.split('\}', child_element.tag)[1]
+    local_name = re.split(r'}', child_element.tag)[1]
     candidate_matches = parent_element.xpath(
         'cppa:{}'.format(local_name),
         namespaces=_NSMAP
@@ -483,7 +483,7 @@ def match_channel_reference_element(cpp, parent_element, cpa, child_element, dir
         match_channels(cpp, cpp_channel_id, cpa, child_element.text, direction)
 
 def match_certificate_reference_element(cpp, parent_element, cpa, child_element):
-    local_name = re.split('\}', child_element.tag)[1]
+    local_name = re.split(r'}', child_element.tag)[1]
     logging.error('match_certificate_reference_element for {}'.format(local_name))
     candidate_matches = parent_element.xpath(
         'cppa:{}'.format(local_name),
