@@ -2,7 +2,7 @@ __author__ = 'pvde'
 
 from lxml import etree
 
-import logging, json, os, traceback
+import logging, traceback
 
 from jsonschema import validate
 
@@ -907,7 +907,7 @@ def process_sender_error_channel(cpa, pmode, leg, errhandl):
     if sendererrchannelid != None:
         sendererrch = channel(cpa,sendererrchannelid)
         addr = channel_transport_address(cpa, sendererrchannelid)
-        pmode[leg]['ErrorHandling']['Report']['SenderErrorsTo']
+        pmode[leg]['ErrorHandling']['Report']['SenderErrorsTo'] = addr
 
 
 def process_reliability(cpa, pmode, leg, channel):
