@@ -10,7 +10,7 @@ A ChannelProfileHandler class
 from lxml import etree
 from copy import deepcopy
 import logging
-from schema import cppa3_content_model as cppa3_content_model
+from .schema import cppa3_content_model as cppa3_content_model
 
 logging.basicConfig(level=logging.DEBUG)
 
