@@ -40,7 +40,7 @@ class ProfileTestCase( unittest.TestCase ):
     def test_0001(self):
         logging.info('Test 0001')
         data = etree.fromstring("""<?xml version="1.0"
-        encoding="UTF-8"?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
+         ?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
         <cppa:ebMS3Channel
         xmlns:pycppa3="https://pypi.python.org/pypi/cppa3">
             <cppa:ChannelProfile>http://docs.oasis-open.org/ebxml-msg/ebms/v3.0/ns/cprofiles/200809/as4ebhandler</cppa:ChannelProfile>
@@ -73,7 +73,7 @@ class ProfileTestCase( unittest.TestCase ):
     def test_0002(self):
         logging.info('Test 0002')
         data = etree.fromstring("""<?xml version="1.0"
-        encoding="UTF-8"?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
+         ?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
         <cppa:ebMS3Channel
         xmlns:pycppa3="https://pypi.python.org/pypi/cppa3">
             <cppa:ChannelProfile>multi_enc_alg</cppa:ChannelProfile>
@@ -103,7 +103,7 @@ class ProfileTestCase( unittest.TestCase ):
     def test_0003(self):
         logging.info('Test 0003')
         data = etree.fromstring("""<?xml version="1.0"
-        encoding="UTF-8"?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
+         ?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
         <cppa:ebMS3Channel
         xmlns:pycppa3="https://pypi.python.org/pypi/cppa3">
             <cppa:ChannelProfile>multi_enc_alg</cppa:ChannelProfile>
@@ -135,7 +135,7 @@ class ProfileTestCase( unittest.TestCase ):
     def test_0004(self):
         logging.info('Test 0004')
         data = etree.fromstring("""<?xml version="1.0"
-        encoding="UTF-8"?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
+         ?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
         <cppa:ebMS3Channel
         xmlns:pycppa3="https://pypi.python.org/pypi/cppa3">
             <cppa:ChannelProfile>multi_enc_alg</cppa:ChannelProfile>
@@ -170,7 +170,7 @@ class ProfileTestCase( unittest.TestCase ):
     def test_0005(self):
         logging.info('Test 0005')
         data = etree.fromstring("""<?xml version="1.0"
-        encoding="UTF-8"?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
+         ?><cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
         <cppa:ebMS3Channel
         xmlns:pycppa3="https://pypi.python.org/pypi/cppa3">
             <cppa:ChannelProfile>multi_enc_alg</cppa:ChannelProfile>
@@ -205,7 +205,7 @@ class ProfileTestCase( unittest.TestCase ):
     #@unittest.skip('Fix later')
     def test_0006(self):
         logging.info('Test 0006')
-        data = etree.fromstring("""<?xml version="1.0" encoding="UTF-8"?>
+        data = etree.fromstring("""<?xml version="1.0"  ?>
         <cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
 <cppa:ebMS3Channel package="entsog_package">
     <cppa:ChannelProfile>http://www.entsog.eu/publications/as4#AS4-USAGE-PROFILE/v2.0/UserMessageChannel</cppa:ChannelProfile>
@@ -274,7 +274,7 @@ class ProfileTestCase( unittest.TestCase ):
 
     def test_0007(self):
         logging.info('Test 0007')
-        data = etree.fromstring("""<?xml version="1.0" encoding="UTF-8"?>
+        data = etree.fromstring("""<?xml version="1.0"  ?>
         <cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
   <cppa:ebMS3Channel id="ch_receive" transport="tr_receive" package="entsog_package">
     <cppa:Description xml:lang="en">Channel for incoming ENTSOG AS4 User Messages</cppa:Description>
